/*
	Build process handler for Seismic Bencmark Processes
	This process takes a list of process names from the
	standard input and writes Fortran subroutines 'sysprep'
	and 'sysproc' to standard output.
*/

#include <stdio.h>
#include <ctype.h>

#define MAXPROC 25

char PNAM[MAXPROC][5];

main()
{
	int i,n;
	char buf[5],*fgets();

/* loop and read process names */
	i = 0;
	while ( (n = getnlin(buf,5)) != EOF ) 
		if ( (buf[0] != '#') && (n == 5) )
			strcpy(PNAM[i++],buf);

/* if no process names, exit with error code */
	if (i==0) exit(-1);
	n = i;

/*--------------------------------------------------------------------*/
/* PREP handler
/*--------------------------------------------------------------------*/

/* Write prologue to standard output */
	printf("C*\nC*\tARCO Seismic Benchmark Process Handler\nC*\n");
	printf("      integer function sysprep(name, ldim, maxtrc,");
	printf(" nra, nsa, abort, ipr)\n");
	printf("      character*4 name\n");
	printf("      integer ldim, maxtrc, nra, nsa, ipr\n");
	printf("      logical abort\n");
	printf("      include 'para.inc'\n");
	printf("      uprep = 0\n");
	printf("      sysprep = 0\n");  /* Set function for some compilers MS */

/* First statement in if/else block */
	strupper(buf,PNAM[0]);
	printf("      if (name.eq.'%s') then\n",buf);
	printf("          if (node.eq.master) then\n");
	printf("          call %sP( ldim, maxtrc, nra, nsa, abort, ipr)\n",
		buf);
	printf("          endif\n");
	printf("          call %sCOM()\n",buf);

/* Remaining statements */
	for (i=1; i<n; i++) {
		strupper(buf,PNAM[i]);
		printf("      else if (name.eq.'%s') then\n",buf);
		printf("          if (node.eq.master) then\n");
		printf("          call %sP( ldim, maxtrc, nra, nsa,", buf); 
		printf(" abort, ipr)\n");
		printf("          endif\n");
		printf("          call %sCOM()\n",buf);
	}

/* Postfix code */
	printf("      else\n");
	printf("          uprep = -1\n");
	printf("      endif\n");
	printf("      return\n");
	printf("      end function sysprep\n");                       

/*--------------------------------------------------------------------*/
/* Common block handlers
/*--------------------------------------------------------------------*/

/* Subroutine handler for each process */
	for (i=0; i<n; i++) {
		strlower(buf,PNAM[i]);
		printf("\n");
		printf("      subroutine %scom\n",buf);
		printf("      include '%s.inc'\n",buf);
		printf("      call sysbcst( %s_start, %s_end )\n",buf,buf);
		printf("      return\n");
		printf("      end\n");
	}

/*--------------------------------------------------------------------*/
/* PROC handler
/*--------------------------------------------------------------------*/

/* Write prologue to standard output */
	printf("\n");
	printf("      integer function sysproc( name, x, ldim, maxtrc, otr,\n");
	printf("     +    nra, ra, nsa, sa, ntri, ntro, abort, ipr )\n");
	printf("      character*4 name\n");
	printf("      character*1 x\n");
	printf("      integer ldim, maxtrc, nra, nsa, ntri, ntro, ipr\n");
	printf("      logical abort\n");
	printf("      uproc = 0\n");
	printf("      sysproc = 0\n");  /* Set function for some compilers MS */

/* Construct if/then/else block */
	for (i=0; i<n; i++) {
		if (i) 
			printf("      else if ");
		else
			printf("      if ");
		strupper(buf,PNAM[i]);
		printf("(name.eq.'%s') then\n",buf);
		printf("        if (x.eq.'A') then\n");
		printf("            call %sA( ldim, maxtrc, otr,\n", buf);
		printf("     +         nra, ra, nsa, sa, abort, ipr )\n");
		printf("        else if (x.eq.'B') then\n");
		printf("            call %sB( ldim, maxtrc, otr,\n", buf);
		printf("     +         nra, ra, nsa, sa, ntri, ntro,"); 
		printf(" abort, ipr )\n");
		printf("        else\n");
		printf("            call %sC( ldim, maxtrc, otr,\n", buf);
		printf("     +         nra, ra, nsa, sa, ntro, abort, ipr )\n");
		printf("        endif\n");
	}

/* Postfix code */

	printf("      else\n");
	printf("          uproc = -1\n");
	printf("      endif\n");
	printf("      return\n");
	printf("      end function sysproc\n");
	
	exit(0);
}

/**********************************************************************/

getnlin(buf,n)
/*
	Move n-1 characters from standard input to buf, then
	discard any remaining characters on the line. Last element
	of buf is set to NULL.
*/
char *buf;
int n;
{
	int i;
	char c;

/* Read n-1 characters or end-of-line */
	for (i=0; i<(n-1); i++) {
		c = (char)getchar();
		if ( (c == '\n') || (c == (char)EOF) )
			break;
		*buf++ = c;
	}
	*buf = '\0';

/* Return EOF if no characters read */
	if ( (i==0) && (c==(char)EOF) ) return( EOF );

/* Return if EOL was reached */
	i++;
	if (c == '\n') return(i);

/* Read characters until EOL or EOF */
	do {
		c = (char)getchar();
	} while ( (c != '\n') && (c != (char)EOF) ) ;

	return(i);

}

/**********************************************************************/

strupper(to,from)
/*
	Convert to upper case
*/
char *to,*from;
{
	while (*from) {
		if (islower(*from))
			*to = toupper(*from);
		else
			*to = *from;
		to++;
		from++;
	}
}

strlower(to,from)
/*
	Convert string to lower case
*/
char *to,*from;
{
	while (*from) {
		if (isupper(*from))
			*to = tolower(*from);
		else
			*to = *from;
		to++;
		from++;
	}
}

/**********************************************************************/
