C*----------------------------------------------------------------------
C*
C*  NAME:
C*    sysprep - call seimic processing preparatory routine
C*     
C*  SYNOPSIS:
C*    character*4 name
C*    integer ldim, maxtrc, nra, nsa, ipr
C*    logical abort
C*    call sysprep( name, ldim, maxtrc, nra, nsa, abort, ipr )
C*
C*  DESCRIPTION: 
C*    Searches for process that matches 'name' and calls the
C*    appropriate initialization routine.
C*    Exits via routine 'sysexit' if no match found.
C*
C*----------------------------------------------------------------------
C*   DEPENDENCIES:
C*
C*     Subroutines:
C*       sysexit
C*
C*     Libraries:
C*       FORTRAN I/O support
C*
C*----------------------------------------------------------------------
C*   HISTORY:
C*
C*      Written:
C*        12/31/91 - C. Mosher, ARCO E&PT 
C*
C*      References:
C*
C*      Modified:
C*
C*----------------------------------------------------------------------
C
	subroutine sysprep( name, ldim, maxtrc, nra, nsa, abort, ipr )
	character*4 name
	integer ldim, maxtrc, nra, nsa, ipr
	logical abort
	character*72 buf
	include 'para.inc'

	if (name.eq.'DCON') then
		if (node.eq.master) then
			call DCONP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call dconcom( )
	else if (name.eq.'DGEN') then
		if (node.eq.master) then
			call DGENP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call dgencom( )
	else if (name.eq.'DMOC') then
		if (node.eq.master) then
			call DMOCP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call dmoccom( )
	else if (name.eq.'FANF') then
		if (node.eq.master) then
			call FANFP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call fanfcom( )
	else if (name.eq.'FDMD') then
		if (node.eq.master) then
			call FDMDP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call fdmdcom( )
	else if (name.eq.'FXMG') then
		if (node.eq.master) then
			call FXMGP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call fxmgcom( )
	else if (name.eq.'GEOM') then
		if (node.eq.master) then
			call GEOMP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call geomcom( )
	else if (name.eq.'MG3D') then
		if (node.eq.master) then
			call MG3DP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call mg3dcom( )
	else if (name.eq.'M3FK') then
		if (node.eq.master) then
			call M3FKP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call m3fkcom( )
	else if (name.eq.'NMOC') then
		if (node.eq.master) then
			call NMOCP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call nmoccom( )
	else if (name.eq.'RATE') then
		if (node.eq.master) then
			call RATEP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call ratecom( )
	else if (name.eq.'READ') then
		if (node.eq.master) then
			call READP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call readcom( )
	else if (name.eq.'STAK') then
		if (node.eq.master) then
			call STAKP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call stakcom( )
	else if (name.eq.'WRIT') then
		if (node.eq.master) then
			call WRITP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call writcom( )
	else if (name.eq.'XSUM') then
		if (node.eq.master) then
			call XSUMP(	ldim, maxtrc, nra, nsa, abort, ipr )		
		endif
		call xsumcom( )
	else
		write (buf,9010) name
 9010   format (' *** SEIS ERROR: Process ',a4,' is not defined')
		call sysexit( buf )
	endif
	return
	end

C*----------------------------------------------------------------------

	subroutine dconcom()
	include 'dcon.inc'
	call sysbcst( dcon_start, dcon_end )
	return
	end

	subroutine dgencom()
	include 'dgen.inc'
	call sysbcst( dgen_start, dgen_end )
	return
	end

	subroutine dmoccom()
	include 'dmoc.inc'
	call sysbcst( dmoc_start, dmoc_end )
	return
	end

	subroutine fanfcom()
	include 'fanf.inc'
	call sysbcst( fanf_start, fanf_end )
	return
	end

	subroutine fdmdcom()
	include 'fdmd.inc'
	call sysbcst( fdmd_start, fdmd_end )
	return
	end

	subroutine fxmgcom()
	include 'fxmg.inc'
	call sysbcst( fxmg_start, fxmg_end )
	return
	end

	subroutine geomcom()
	include 'geom.inc'
	call sysbcst( geom_start, geom_end )
	return
	end

	subroutine mg3dcom()
	include 'mg3d.inc'
	call sysbcst( mg3d_start, mg3d_end )
	return
	end

	subroutine m3fkcom()
	include 'm3fk.inc'
	call sysbcst( m3fk_start, m3fk_end )
	return
	end

	subroutine nmoccom()
	include 'nmoc.inc'
	call sysbcst( nmoc_start, nmoc_end )
	return
	end

	subroutine ratecom()
	include 'rate.inc'
	call sysbcst( rate_start, rate_end )
	return
	end

	subroutine readcom()
	include 'read.inc'
	call sysbcst( read_start, read_end )
	return
	end

	subroutine stakcom()
	include 'stak.inc'
	call sysbcst( stak_start, stak_end )
	return
	end

	subroutine writcom()
	include 'writ.inc'
	call sysbcst( writ_start, writ_end )
	return
	end

	subroutine xsumcom()
	include 'xsum.inc'
	call sysbcst( xsum_start, xsum_end )
	return
	end
